@@ -12,6 +12,7 @@ from ._run import UvVenvRunner
 from ._run_lock import UvVenvLockRunner
 
 if TYPE_CHECKING:
+    from tox.config.cli.parser import ToxParser
     from tox.tox_env.register import ToxEnvRegister
 
 
@@ -24,6 +25,17 @@ def tox_register_tox_env(register: ToxEnvRegister) -> None:
     register._default_run_env = UvVenvRunner.id()  # noqa: SLF001
 
 
+@impl
+def tox_add_option(parser: ToxParser) -> None:
+    for key in ("run", "exec"):
+        parser.handlers[key][0].add_argument(
+            "--skip-uv-sync",
+            dest="skip_uv_sync",
+            help="skip uv sync (lock mode only)",
+            action="store_true",
+        )
+
+
 def tox_append_version_info() -> str:
     return f"with uv=={version('uv')}"
 
