@@ -231,13 +231,16 @@ def test_uv_lock_with_install_pkg(tox_project: ToxProjectCreator, name: str) ->
 
 
 @pytest.mark.usefixtures("clear_python_preference_env_var")
-def test_uv_sync_extra_flags(tox_project: ToxProjectCreator) -> None:
+@pytest.mark.parametrize("uv_sync_locked", [True, False])
+def test_uv_sync_extra_flags(tox_project: ToxProjectCreator, uv_sync_locked: bool) -> None:
+    uv_sync_locked_str = str(uv_sync_locked).lower()
     project = tox_project({
-        "tox.ini": """
+        "tox.ini": f"""
     [testenv]
     runner = uv-venv-lock-runner
     no_default_groups = false
     uv_sync_flags = --no-editable, --inexact
+    uv_sync_locked = {uv_sync_locked_str}
     commands = python hello
     """
     })
@@ -269,7 +272,7 @@ def test_uv_sync_extra_flags(tox_project: ToxProjectCreator) -> None:
             [
                 "uv",
                 "sync",
-                "--locked",
+                *(["--locked"] if uv_sync_locked else []),
                 "--python-preference",
                 "system",
                 "--no-editable",
@@ -609,3 +612,54 @@ def test_skip_uv_package_skip(tox_project: ToxProjectCreator, monkeypatch: pytes
         ),
     ]
     assert calls == expected
+
+
+@pytest.mark.usefixtures("clear_python_preference_env_var")
+def test_uv_lock_ith_resolution(tox_project: ToxProjectCreator) -> None:
+    project = tox_project({
+        "tox.ini": """
+    [testenv]
+    runner = uv-venv-lock-runner
+    uv_resolution = highest
+    """
+    })
+    execute_calls = project.patch_execute(lambda r: 0 if r.run_id != "venv" else None)
+    result = project.run("run", "--notest")
+    result.assert_success()
+
+    calls = [(i[0][0].conf.name, i[0][3].run_id, i[0][3].cmd) for i in execute_calls.call_args_list]
+    uv = find_uv_bin()
+    expected = [
+        (
+            "py",
+            "venv",
+            [
+                uv,
+                "venv",
+                "-p",
+                sys.executable,
+                "--allow-existing",
+                "--python-preference",
+                "system",
+                str(project.path / ".tox" / "py"),
+            ],
+        ),
+        (
+            "py",
+            "uv-sync",
+            [
+                "uv",
+                "sync",
+                "--locked",
+                "--python-preference",
+                "system",
+                "--resolution",
+                "highest",
+                "-p",
+                sys.executable,
+            ],
+        ),
+    ]
+    assert len(calls) == len(expected)
+    for i in range(len(calls)):
+        assert calls[i] == expected[i]
