@@ -99,6 +99,10 @@ def test_uv_venv_spec_major_only(tox_project: ToxProjectCreator) -> None:
     result.assert_success()
 
 
+@pytest.mark.xfail(
+    sys.platform == "win32",
+    reason="Bug https://github.com/tox-dev/tox-uv/issues/193 https://github.com/astral-sh/uv/issues/14239",
+)
 @pytest.mark.parametrize(
     ("pypy", "expected_uv_pypy"),
     [
@@ -133,7 +137,7 @@ def test_uv_venv_spec_pypy(
     project = tox_project({"tox.ini": f"[tox]\nenv_list = {pypy}"})
     try:
         result = project.run("config", "-vv")
-    except tox.tox_env.errors.Skip:
+    except tox.tox_env.errors.Skip:  # pragma: win32 no cover
         stdout, _ = capfd.readouterr()
     else:  # pragma: no cover (PyPy might not be available on the system)
         stdout = result.out
@@ -208,15 +212,25 @@ def other_interpreter_exe() -> pathlib.Path:  # pragma: no cover
     return base_python
 
 
-def test_uv_venv_spec_abs_path(tox_project: ToxProjectCreator, other_interpreter_exe: pathlib.Path) -> None:
+@pytest.mark.xfail(
+    sys.platform == "win32",
+    reason="Bug https://github.com/tox-dev/tox-uv/issues/193 https://github.com/astral-sh/uv/issues/14239",
+)
+def test_uv_venv_spec_abs_path(
+    tox_project: ToxProjectCreator, other_interpreter_exe: pathlib.Path
+) -> None:  # pragma: win32 no cover
     project = tox_project({"tox.ini": f"[testenv]\npackage=skip\nbase_python={other_interpreter_exe}"})
     result = project.run("-vv")
     result.assert_success()
 
 
+@pytest.mark.xfail(
+    sys.platform == "win32",
+    reason="Bug https://github.com/tox-dev/tox-uv/issues/193 https://github.com/astral-sh/uv/issues/14239",
+)
 def test_uv_venv_spec_abs_path_conflict_ver(
     tox_project: ToxProjectCreator, other_interpreter_exe: pathlib.Path
-) -> None:
+) -> None:  # pragma: win32 no cover
     # py27 is long gone, but still matches the testenv capture regex, so we know it will fail
     project = tox_project({"tox.ini": f"[testenv:py27]\npackage=skip\nbase_python={other_interpreter_exe}"})
     result = project.run("-vv", "-e", "py27")
@@ -224,9 +238,13 @@ def test_uv_venv_spec_abs_path_conflict_ver(
     assert f"failed with env name py27 conflicting with base python {other_interpreter_exe}" in result.out
 
 
+@pytest.mark.xfail(
+    sys.platform == "win32",
+    reason="Bug https://github.com/tox-dev/tox-uv/issues/193 https://github.com/astral-sh/uv/issues/14239",
+)
 def test_uv_venv_spec_abs_path_conflict_impl(
     tox_project: ToxProjectCreator, other_interpreter_exe: pathlib.Path
-) -> None:
+) -> None:  # pragma: win32 no cover
     env = "pypy" if platform.python_implementation() == "CPython" else "cpython"
     project = tox_project({"tox.ini": f"[testenv:{env}]\npackage=skip\nbase_python={other_interpreter_exe}"})
     result = project.run("-vv", "-e", env)
@@ -244,12 +262,23 @@ def test_uv_venv_na(tox_project: ToxProjectCreator) -> None:
     result.assert_failed(code=-1)
 
 
+def test_uv_venv_na_uv_072(tox_project: ToxProjectCreator) -> None:
+    # Test uv==0.7.2
+    # skip_missing_interpreters is true by default
+    project = tox_project({"tox.ini": "[testenv]\npackage=skip\nbase_python=1.0\nrequires=uv==0.7.2"})
+    result = project.run("-vv")
+
+    # When a Python interpreter is missing in a pytest environment, project.run
+    # return code is equal to -1
+    result.assert_failed(code=-1)
+
+
 def test_uv_venv_skip_missing_interpreters_fail(tox_project: ToxProjectCreator) -> None:
     project = tox_project({
         "tox.ini": "[tox]\nskip_missing_interpreters=false\n[testenv]\npackage=skip\nbase_python=1.0"
     })
     result = project.run("-vv")
-    result.assert_failed(code=1)
+    result.assert_failed(code=2)
 
 
 def test_uv_venv_skip_missing_interpreters_pass(tox_project: ToxProjectCreator) -> None:
@@ -447,6 +476,14 @@ def test_get_python_architecture(base_python: str, architecture: int | None) ->
     assert python_info.extra["architecture"] == architecture
 
 
+@pytest.mark.parametrize(("base_python", "is_free_threaded"), [("py313", False), ("py313t", True)])
+def test_get_python_free_threaded(base_python: str, is_free_threaded: int | None) -> None:
+    uv_venv = _TestUvVenv(create_args=mock.Mock())
+    python_info = uv_venv.get_python_info(base_python)
+    assert python_info is not None
+    assert python_info.free_threaded == is_free_threaded
+
+
 def test_env_version_spec_no_architecture() -> None:
     uv_venv = _TestUvVenv(create_args=mock.MagicMock())
     python_info = PythonInfo(
@@ -510,3 +547,25 @@ def test_env_version_spec_architecture_configured_overwrite_sys_exe() -> None:
     )
     uv_venv.set_base_python(python_info)
     assert uv_venv.env_version_spec() == f"cpython-{major}.{minor}-windows-x86-none"
+
+
+def test_env_version_spec_free_threaded() -> None:
+    uv_venv = _TestUvVenv(create_args=mock.MagicMock())
+    python_info = PythonInfo(
+        implementation="cpython",
+        version_info=VersionInfo(
+            major=3,
+            minor=13,
+            micro=3,
+            releaselevel="",
+            serial=0,
+        ),
+        version="",
+        is_64=True,
+        platform="win32",
+        extra={"architecture": None},
+        free_threaded=True,
+    )
+    uv_venv.set_base_python(python_info)
+    with mock.patch("sys.version_info", (0, 0, 0)):  # prevent picking sys.executable
+        assert uv_venv.env_version_spec() == "cpython3.13+freethreaded"
